//+------------------------------------------------------------------+
//|                                                 ATR Channels.mq4 |
//|                         Copyright  2005, Luis Guilherme Damiani |
//|                                      http://www.damianifx.com.br |
//+------------------------------------------------------------------+

#property copyright "Copyright  2005, Luis Guilherme Damiani"
#property link      "http://www.damianifx.com.br"
#property indicator_chart_window
#property  indicator_buffers 7
#property  indicator_color1  Magenta //Moving Average
#property  indicator_color2  DeepSkyBlue // Lower band 1
#property  indicator_color3  DeepSkyBlue // Upper band 1
#property  indicator_color4  RoyalBlue // Lower band 2
#property  indicator_color5  RoyalBlue // Upper band 2
#property  indicator_color6  BlueViolet // Lower band 3
#property  indicator_color7  BlueViolet // Upper band 3
//---- indicator buffers
double     MA_Buffer0[];
double     Ch1up_Buffer1[];
double     Ch1dn_Buffer2[];
double     Ch2up_Buffer3[];
double     Ch2dn_Buffer4[];
double     Ch3up_Buffer5[];
double     Ch3dn_Buffer6[];

//---- input parameters
extern int       PeriodsATR=26;
extern int       MA_Periods=16;
extern int       MA_type=MODE_SMMA;
extern double       Mult_Factor1= 1.6;
extern double       Mult_Factor2= 3.2;
extern double       Mult_Factor3= 4.8;
int patr, map;
double mf1, mf2, mf3;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
  string mat;
 
//---7- indicators
// MA
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,MA_Buffer0);
   SetIndexDrawBegin(0,0);
   /*if (MA_type==MODE_LWMA)SetIndexLabel(0,"WMA"+MA_Periods) else 
   {
      if (MA_type==MODE_SMA) SetIndexLabel(0,"SMA"+MA_Periods) else
      {
         if (MA_type==MODE_EMA) SetIndexLabel(0,"EMA"+MA_Periods) else 
         SetIndexLabel(0,"SMMA"+MA_Periods);
      }; 
   };*/      
  // ATR 1 up
   SetIndexStyle(1,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(1,Ch1up_Buffer1);
   SetIndexDrawBegin(1,0);
   SetIndexLabel(1,"ATRu "+PeriodsATR+", "+Mult_Factor1);
  // ATR 1 down
   SetIndexStyle(2,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(2,Ch1dn_Buffer2);
   SetIndexDrawBegin(2,0);
   SetIndexLabel(2,"ATRd "+PeriodsATR+", "+Mult_Factor1);
// ATR 2 up
   SetIndexStyle(3,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(3,Ch2up_Buffer3);
   SetIndexDrawBegin(3,0);
   SetIndexLabel(3,"ATRu "+PeriodsATR+", "+Mult_Factor2);
  // ATR 2 down
   SetIndexStyle(4,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(4,Ch2dn_Buffer4);
   SetIndexDrawBegin(4,0);
   SetIndexLabel(4,"ATRd "+PeriodsATR+", "+Mult_Factor2);
   // ATR 3 up
   SetIndexStyle(5,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(5,Ch3up_Buffer5);
   SetIndexDrawBegin(5,0);
   SetIndexLabel(5,"ATRu "+PeriodsATR+", "+Mult_Factor3);
  // ATR 3 down
   SetIndexStyle(6,DRAW_LINE, STYLE_DOT);
   SetIndexBuffer(6,Ch3dn_Buffer6);
   SetIndexDrawBegin(6,0);
   SetIndexLabel(6,"ATRd "+PeriodsATR+", "+Mult_Factor3);
//----

   patr = PeriodsATR;
   map = MA_Periods;
   mf1 = Mult_Factor1;
   mf2 = Mult_Factor2;
   mf3 = Mult_Factor3;

   switch (Period())
   {
     case PERIOD_M1:
       map = MA_Periods * 1.2;
       mf1 = mf1 * 1.2;
       mf2 = mf2 * 1.2;
       mf3 = mf3 * 1.2;
       break;
     case PERIOD_M5:
       break;
     case PERIOD_M15:
       map = MA_Periods * 0.9;
       mf1 = mf1 * 0.9;
       mf2 = mf2 * 0.9;
       mf3 = mf3 * 0.9;
       break;
     case PERIOD_M30:
       map = MA_Periods * 0.8;
       mf1 = mf1 * 0.8;
       mf2 = mf2 * 0.8;
       mf3 = mf3 * 0.8;
       break;
     case PERIOD_H1:
       map = MA_Periods * 0.7;
       mf1 = mf1 * 0.7;
       mf2 = mf2 * 0.7;
       mf3 = mf3 * 0.7;
       break;
     case PERIOD_H4:
       map = MA_Periods * 0.6;
       mf1 = mf1 * 0.6;
       mf2 = mf2 * 0.6;
       mf3 = mf3 * 0.6;
       break;
     default:
       map = MA_Periods * 0.5;
       mf1 = mf1 * 0.5;
       mf2 = mf2 * 0.5;
       mf3 = mf3 * 0.5;
       break;
   }
   
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {//---- 
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int fixed_bars=IndicatorCounted();
   for(int i=0;i< Bars - fixed_bars;i++)
     {
         double atr=iATR(NULL,0,patr,i);
         double ma=iMA(NULL,0,map,0,MA_type,PRICE_TYPICAL,i);
         MA_Buffer0[i]=ma;
         Ch1up_Buffer1[i]=ma+atr*mf1;
         Ch1dn_Buffer2[i]=ma-atr*mf1;
         
         Ch2up_Buffer3[i]=ma+atr*mf2;
         Ch2dn_Buffer4[i]=ma-atr*mf2;
         
         Ch3up_Buffer5[i]=ma+atr*mf3;
         Ch3dn_Buffer6[i]=ma-atr*mf3;
      }  
   
//---- 
   
//----
   return(0);
  }



